prometa package
===============

Submodules
----------

prometa.citation module
-----------------------

.. automodule:: prometa.citation
   :members:
   :undoc-members:
   :show-inheritance:

prometa.codemeta module
-----------------------

.. automodule:: prometa.codemeta
   :members:
   :undoc-members:
   :show-inheritance:

prometa.common module
---------------------

.. automodule:: prometa.common
   :members:
   :undoc-members:
   :show-inheritance:

prometa.config module
---------------------

.. automodule:: prometa.config
   :members:
   :undoc-members:
   :show-inheritance:

prometa.file module
-------------------

.. automodule:: prometa.file
   :members:
   :undoc-members:
   :show-inheritance:

prometa.insert module
---------------------

.. automodule:: prometa.insert
   :members:
   :undoc-members:
   :show-inheritance:

prometa.main module
-------------------

.. automodule:: prometa.main
   :members:
   :undoc-members:
   :show-inheritance:

prometa.project module
----------------------

.. automodule:: prometa.project
   :members:
   :undoc-members:
   :show-inheritance:

prometa.readme module
---------------------

.. automodule:: prometa.readme
   :members:
   :undoc-members:
   :show-inheritance:

prometa.version module
----------------------

.. automodule:: prometa.version
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: prometa
   :members:
   :undoc-members:
   :show-inheritance:
